@@ -10,10 +10,11 @@ from . import config_iterators
 from . import config_splitters
 from .abstract_dd import AbstractDD
 from .abstract_parallel_dd import AbstractParallelDD
-from .cli import __version__, call
+from .cli import __version__, reduce
 from .combined_iterator import CombinedIterator
 from .combined_parallel_dd import CombinedParallelDD
 from .dd import DD
+from .outcome import Outcome
 from .outcome_cache import ConfigCache, ContentCache, OutcomeCache
 from .parallel_dd import ParallelDD
 from .shared_cache import shared_cache_decorator
