@@ -7,10 +7,10 @@
 
 import argparse
 import codecs
-import multiprocessing
 import os
 import time
 
+from multiprocessing import cpu_count
 from os.path import basename, exists, join, realpath
 from shutil import rmtree
 
@@ -64,7 +64,7 @@ def create_parser():
                         help='run DD in parallel')
     parser.add_argument('-c', '--combine-loops', action='store_true', default=False,
                         help='combine subset and complement check loops for more parallelization (has effect in parallel mode only)')
-    parser.add_argument('-j', '--jobs', metavar='N', type=int, default=multiprocessing.cpu_count(),
+    parser.add_argument('-j', '--jobs', metavar='N', type=int, default=cpu_count(),
                         help='maximum number of test commands to execute in parallel (has effect in parallel mode only; default: %(default)s)')
     parser.add_argument('-u', '--max-utilization', metavar='N', type=int, default=100,
                         help='maximum CPU utilization allowed; don\'t start new parallel jobs until utilization is higher (has effect in parallel mode only; default: %(default)s)')
@@ -83,15 +83,17 @@ def create_parser():
     inators.arg.add_log_level_argument(parser)
     parser.add_argument('-o', '--out', metavar='DIR',
                         help='working directory (default: input.timestamp)')
-    parser.add_argument('--disable-cleanup', dest='cleanup', default=True, action='store_false',
+    parser.add_argument('--no-cleanup', dest='cleanup', default=True, action='store_false',
                         help='disable the removal of generated temporary files')
     return parser
 
 
-def process_args(parser, args):
+def process_args(args):
+    inators.arg.process_log_level_argument(args, logger)
+
     args.input = realpath(args.input)
     if not exists(args.input):
-        parser.error('Test case does not exist: %s' % args.input)
+        raise ValueError('Test case does not exist: %s' % args.input)
 
     with open(args.input, 'rb') as f:
         args.src = f.read()
@@ -99,21 +101,25 @@ def process_args(parser, args):
     if args.encoding:
         try:
             codecs.lookup(args.encoding)
-        except LookupError:
-            parser.error('The given encoding (%s) is not known.' % args.encoding)
+        except LookupError as e:
+            raise ValueError('The given encoding (%s) is not known.' % args.encoding) from e
     else:
         args.encoding = chardet.detect(args.src)['encoding'] or 'latin-1'
 
+    args.src = args.src.decode(args.encoding)
+
+    args.out = realpath(args.out if args.out else '%s.%s' % (args.input, time.strftime('%Y%m%d_%H%M%S')))
+
     args.test = realpath(args.test)
     if not exists(args.test) or not os.access(args.test, os.X_OK):
-        parser.error('Tester program does not exist or isn\'t executable: %s' % args.test)
+        raise ValueError('Tester program does not exist or isn\'t executable: %s' % args.test)
 
     args.tester_class = SubprocessTest
-    args.tester_config = {
-        'encoding': args.encoding,
-        'command_pattern': [args.test, '%s'],
-        'cleanup': args.cleanup,
-    }
+    args.tester_config = dict(command_pattern=[args.test, '%s'],
+                              work_dir=join(args.out, 'tests'),
+                              filename=basename(args.input),
+                              encoding=args.encoding,
+                              cleanup=args.cleanup)
 
     args.cache = getattr(outcome_cache, args.cache)
     if args.parallel:
@@ -124,28 +130,25 @@ def process_args(parser, args):
     complement_iterator = getattr(config_iterators, args.complement_iterator)
 
     # Choose the reducer class that will be used and its configuration.
-    args.reduce_config = {'split': split_class(n=args.granularity)}
     if not args.parallel:
         args.reduce_class = DD
-        args.reduce_config['subset_iterator'] = subset_iterator
-        args.reduce_config['complement_iterator'] = complement_iterator
-        args.reduce_config['subset_first'] = args.subset_first
+        args.reduce_config = dict(subset_iterator=subset_iterator,
+                                  complement_iterator=complement_iterator,
+                                  subset_first=args.subset_first)
     else:
-        args.reduce_config['proc_num'] = args.jobs
-        args.reduce_config['max_utilization'] = args.max_utilization
-
         if args.combine_loops:
             args.reduce_class = CombinedParallelDD
-            args.reduce_config['config_iterator'] = CombinedIterator(args.subset_first,
-                                                                     subset_iterator,
-                                                                     complement_iterator)
+            args.reduce_config = dict(config_iterator=CombinedIterator(args.subset_first, subset_iterator, complement_iterator))
         else:
             args.reduce_class = ParallelDD
-            args.reduce_config['subset_iterator'] = subset_iterator
-            args.reduce_config['complement_iterator'] = complement_iterator
-            args.reduce_config['subset_first'] = args.subset_first
+            args.reduce_config = dict(subset_iterator=subset_iterator,
+                                      complement_iterator=complement_iterator,
+                                      subset_first=args.subset_first)
+        args.reduce_config.update(dict(proc_num=args.jobs,
+                                       max_utilization=args.max_utilization))
+    args.reduce_config.update(dict(split=split_class(n=args.granularity)))
 
-    args.out = realpath(args.out if args.out else '%s.%s' % (args.input, time.strftime('%Y%m%d_%H%M%S')))
+    logger.info('Input loaded from %s', args.input)
 
 
 def log_args(title, args):
@@ -182,14 +185,16 @@ def log_args(title, args):
     logger.info('%s\n\t%s\n', title, '\n\t'.join(_log_args(args)))
 
 
-def call(reduce_class, reduce_config,
-         tester_class, tester_config,
-         input, src, encoding, out,
-         atom='line', cache_class=None, cleanup=True):
+def reduce(src, *,
+           reduce_class, reduce_config,
+           tester_class, tester_config,
+           atom='line',
+           cache_class=None):
     """
     Execute picire as if invoked from command line, however, control its
     behaviour not via command line arguments but function parameters.
 
+    :param src: Contents of the test case to reduce.
     :param reduce_class: Reference to the reducer class.
     :param reduce_config: Dictionary containing information to initialize the
         reduce_class.
@@ -197,93 +202,79 @@ def call(reduce_class, reduce_config,
         interestingness of a test case.
     :param tester_config: Dictionary containing information to initialize the
         tester_class.
-    :param input: Path to the test case to reduce (only used to determine the
-        name of the output file).
-    :param src: Contents of the test case to reduce.
-    :param encoding: Encoding of the input test case.
-    :param out: Path to the output directory.
     :param atom: Input granularity to work with during reduce ('char', 'line',
         or 'both'; default: 'line').
     :param cache_class: Reference to the cache class to use.
-    :param cleanup: Binary flag denoting whether removing auxiliary files at the
-        end is enabled (default: True).
-    :return: The path to the minimal test case.
+    :return: The contents of the minimal test case.
     """
 
     # Get the parameters in a dictionary so that they can be pretty-printed
     # (minus src, as that parameter can be arbitrarily large)
     args = locals().copy()
     del args['src']
-    log_args('Reduce session starts for %s' % input, args)
+    log_args('Reduce session starts', args)
 
-    content = src.decode(encoding)
     cache = cache_class() if cache_class else None
 
-    for current_atom in ['line', 'char']:
-        if atom not in [current_atom, 'both']:
-            continue
-
+    for atom_cnt, atom_name in enumerate(['line', 'char'] if atom == 'both' else [atom]):
         # Split source to the chosen atoms.
-        if atom == 'line':
-            content = content.splitlines(True)
-        logger.info('Initial test contains %d %ss', len(content), current_atom)
+        if atom_name == 'line':
+            src = src.splitlines(True)
+        logger.info('Initial test contains %d %ss', len(src), atom_name)
 
-        tests_dir = join(out, 'tests', current_atom)
-        if not os.path.isdir(tests_dir):
-            os.makedirs(tests_dir)
-
-        test_builder = ConcatTestBuilder(content)
+        test_builder = ConcatTestBuilder(src)
         if cache:
             cache.clear()
             cache.set_test_builder(test_builder)
 
-        dd = reduce_class(tester_class(test_builder=test_builder,
-                                       test_pattern=join(tests_dir, '%s', basename(input)),
-                                       **tester_config),
+        dd = reduce_class(tester_class(test_builder=test_builder, **tester_config),
                           cache=cache,
+                          id_prefix=('a%d' % atom_cnt,),
                           **reduce_config)
-        min_set = dd(list(range(len(content))))
-        content = test_builder(min_set)
+        min_set = dd(list(range(len(src))))
+        src = test_builder(min_set)
 
         logger.trace('The cached results are: %s', cache)
         logger.debug('A minimal config is: %r', min_set)
 
-    out_file = join(out, basename(input))
-    with codecs.open(out_file, 'w', encoding=encoding, errors='ignore') as f:
-        f.write(content)
-    logger.info('Result is saved to %s.', out_file)
+    return src
 
-    if cleanup:
-        rmtree(tests_dir)
 
-    return out_file
+def postprocess(args, out_src):
+    if args.cleanup:
+        rmtree(join(args.out, 'tests'))
+
+    output = join(args.out, basename(args.input))
+    with codecs.open(output, 'w', encoding=args.encoding, errors='ignore') as f:
+        f.write(out_src)
+
+    logger.info('Output saved to %s', output)
 
 
 def execute():
     """
     The main entry point of picire.
     """
+    logging.basicConfig(format='%(message)s')
 
     parser = create_parser()
     # Implementation specific CLI options that are not needed to be part of the core parser.
     parser.add_argument('-a', '--atom', metavar='NAME', choices=['char', 'line', 'both'], default='line',
                         help='atom (i.e., granularity) of input (%(choices)s; default: %(default)s)')
-    inators.arg.add_version_argument(parser, __version__)
-
+    inators.arg.add_version_argument(parser, version=__version__)
     args = parser.parse_args()
-    process_args(parser, args)
 
-    logging.basicConfig(format='%(message)s')
-    inators.arg.process_log_level_argument(args, logger)
+    try:
+        process_args(args)
+    except ValueError as e:
+        parser.error(e)
 
-    call(reduce_class=args.reduce_class,
-         reduce_config=args.reduce_config,
-         tester_class=args.tester_class,
-         tester_config=args.tester_config,
-         input=args.input,
-         src=args.src,
-         encoding=args.encoding,
-         out=args.out,
-         atom=args.atom,
-         cache_class=args.cache,
-         cleanup=args.cleanup)
+    out_src = reduce(args.src,
+                     reduce_class=args.reduce_class,
+                     reduce_config=args.reduce_config,
+                     tester_class=args.tester_class,
+                     tester_config=args.tester_config,
+                     atom=args.atom,
+                     cache_class=args.cache)
+
+    postprocess(args, out_src)
