@@ -1,4 +1,4 @@
-# Copyright (c) 2016-2020 Renata Hodovan, Akos Kiss.
+# Copyright (c) 2016-2021 Renata Hodovan, Akos Kiss.
 #
 # Licensed under the BSD 3-Clause License
 # <LICENSE.rst or https://opensource.org/licenses/BSD-3-Clause>.
@@ -9,34 +9,34 @@ import codecs
 import os
 import shutil
 
-from subprocess import Popen
+from subprocess import run
 
-from .abstract_dd import AbstractDD
+from .outcome import Outcome
 
 
 class SubprocessTest(object):
 
-    def __init__(self, command_pattern, test_builder, test_pattern, encoding, cleanup):
+    def __init__(self, *, test_builder, command_pattern, work_dir, filename, encoding='utf-8', cleanup=True):
         """
         Wrapper around the script provided by the user. It decides about the
         interestingness based on the return code of executed script.
 
+        :param test_builder: Callable object that creates test case from a
+            configuration.
         :param command_pattern: The tester command as a sequence of arguments.
             If an element of the sequence contains %s, it is substituted with
             the path to the test case.
-        :param test_builder: Callable object that creates test case from a
-            configuration.
-        :param test_pattern: The patter of the test's path. It contains one %s
-            part that will be replaced with the ID of the certain
-            configurations.
+        :param work_dir: The work directory where test cases can be saved.
+        :param filename: The file name to use for the test case.
         :param encoding: The encoding that will be used to save the tests.
         :param cleanup: Binary flag denoting whether the test directory should
             be removed after test execution or not.
         """
-        self.command_pattern = command_pattern
-        self.encoding = encoding
         self.test_builder = test_builder
-        self.test_pattern = test_pattern
+        self.command_pattern = command_pattern
+        self.work_dir = work_dir
+        self.filename = filename
+        self.encoding = encoding
         self.cleanup = cleanup
 
     def __call__(self, config, config_id):
@@ -50,11 +50,10 @@ class SubprocessTest(object):
         :return: The evaluation of the current test. It's either FAIL or PASS.
         """
 
-        test_path = self.test_pattern % '_'.join(str(i) for i in config_id)
-        test_dir = os.path.dirname(test_path)
+        test_dir = os.path.join(self.work_dir, '_'.join(str(i) for i in config_id))
+        test_path = os.path.join(test_dir, self.filename)
 
-        if not os.path.isdir(test_dir):
-            os.makedirs(test_dir)
+        os.makedirs(test_dir, exist_ok=True)
 
         with codecs.open(test_path, 'w', encoding=self.encoding, errors='ignore') as f:
             f.write(self.test_builder(config))
@@ -66,14 +65,13 @@ class SubprocessTest(object):
             except TypeError:
                 pass
             args.append(arg)
-        proc = Popen(args, cwd=test_dir)
-        proc.wait()
+        returncode = run(args, cwd=test_dir, check=False).returncode
 
         if self.cleanup:
             shutil.rmtree(test_dir)
 
         # Determine outcome.
-        return AbstractDD.FAIL if proc.returncode == 0 else AbstractDD.PASS
+        return Outcome.FAIL if returncode == 0 else Outcome.PASS
 
 
 class ConcatTestBuilder(object):
