@@ -5,8 +5,8 @@
 # This file may not be copied, modified, or distributed except
 # according to those terms.
 
-import filecmp
 import os
+import platform
 import pytest
 import subprocess
 import sys
@@ -15,29 +15,37 @@ import sys
 is_windows = sys.platform.startswith('win32')
 script_ext = '.bat' if is_windows else '.sh'
 
+is_cpython = platform.python_implementation() == 'CPython'
+
 tests_dir = os.path.dirname(os.path.abspath(__file__))
 resources_dir = os.path.join(tests_dir, 'resources')
 
 
 @pytest.mark.parametrize('test, inp, exp, args_atom', [
-    ('test-json-extra-comma', 'inp-extra-comma.json', 'exp-extra-comma.json', ('--atom=line', )),
+    pytest.param('test-json-extra-comma', 'inp-extra-comma.json', 'exp-extra-comma.json', ('--atom=line', ),
+                 marks=pytest.mark.skipif(not is_cpython, reason='json error messages are implementation-specific')),
     ('test-sumprod10-sum', 'inp-sumprod10.py', 'exp-sumprod10-sum.py', ('--atom=line', )),
     ('test-sumprod10-prod', 'inp-sumprod10.py', 'exp-sumprod10-prod.py', ('--atom=line', )),
-    ('test-json-invalid-escape', 'inp-invalid-escape.json', 'exp-invalid-escape.json', ('--atom=char', )),
-    ('test-json-invalid-escape', 'inp-invalid-escape.json', 'exp-invalid-escape.json', ('--atom=both', )),
+    pytest.param('test-json-invalid-escape', 'inp-invalid-escape.json', 'exp-invalid-escape.json', ('--atom=char', ),
+                 marks=pytest.mark.skipif(not is_cpython, reason='json error messages are implementation-specific')),
+    pytest.param('test-json-invalid-escape', 'inp-invalid-escape.json', 'exp-invalid-escape.json', ('--atom=both', ),
+                 marks=pytest.mark.skipif(not is_cpython, reason='json error messages are implementation-specific')),
 ])
 class TestCli:
 
     def _run_picire(self, test, inp, exp, tmpdir, args):
-        out_dir = '%s' % tmpdir
+        out_dir = str(tmpdir)
         cmd = (sys.executable, '-m', 'picire') \
               + ('--test=' + test + script_ext, '--input=' + inp, '--out=' + out_dir) \
               + ('--log-level=TRACE', ) \
               + args
-        proc = subprocess.Popen(cmd, cwd=resources_dir)
-        proc.communicate()
-        assert proc.returncode == 0
-        assert filecmp.cmp(os.path.join(out_dir, inp), os.path.join(resources_dir, exp))
+        subprocess.run(cmd, cwd=resources_dir, check=True)
+
+        with open(os.path.join(out_dir, inp), 'rb') as outf:
+            outb = outf.read()
+        with open(os.path.join(resources_dir, exp), 'rb') as expf:
+            expb = expf.read()
+        assert outb == expb
 
     @pytest.mark.parametrize('args', [
         ('--split=balanced', '--subset-iterator=forward', '--complement-iterator=forward', '--cache=none'),
